@@ -94,12 +94,12 @@ def __BOND_loads(buf):
 # Recursive repl
 __BOND_TRANS_EXCEPT = None
 
-def __BOND_call(name, args):
+def __BOND_remote(name, args):
     __BOND_sendstate("CALL", __BOND_dumps([name, args]))
     return __BOND_repl()
 
 def __BOND_export(name):
-    globals()[name] = lambda *args: __BOND_call(name, args)
+    globals()[name] = lambda *args: __BOND_remote(name, args)
 
 def __BOND_repl():
     SENTINEL = 1
@@ -131,6 +131,16 @@ def __BOND_repl():
             except Exception as e:
                 err = e
 
+        elif cmd == "XCALL":
+            try:
+                func = eval(args[0], globals())
+                xargs = []
+                for el in args[1]:
+                    xargs.append(el[1] if not el[0] else eval(el[1], globals()))
+                ret = func(*xargs)
+            except Exception as e:
+                err = e
+
         elif cmd == "RETURN":
             return args
 
